@@ -1,4 +1,5 @@
 #include "hs_text_icu.h"
+#include "stdbool.h"
 
 UBreakIterator* __hs_ubrk_open(UBreakIteratorType type, const char *locale,
 			       const UChar *text, int32_t textLength,
@@ -25,7 +26,7 @@ UBreakIterator * __hs_ubrk_safeClone(const UBreakIterator *bi,
     return ubrk_safeClone(bi, stackBuffer, pBufferSize, status);
 }
 
-int32_t __hs_ubrk_current(UBreakIterator *bi)
+int32_t __hs_ubrk_current(const UBreakIterator *bi)
 {
     return ubrk_current(bi);
 }
@@ -305,7 +306,7 @@ int32_t __hs_u_strFoldCase(UChar *dest, int32_t destCapacity,
 
 int32_t __hs_u_strCompareIter(UCharIterator *iter1, UCharIterator *iter2)
 {
-    return u_strCompareIter(iter1, iter2, TRUE);
+    return u_strCompareIter(iter1, iter2, true);
 }
 
 UBlockCode __hs_ublock_getCode(UChar32 c)
@@ -385,8 +386,8 @@ void __hs_uregex_close(URegularExpression *regexp)
     return uregex_close(regexp);
 }
 
-URegularExpression *__hs_uregex_clone(URegularExpression *regexp,
-				      UErrorCode *pErrorCode)
+URegularExpression * __hs_uregex_clone(const URegularExpression *regexp,
+				       UErrorCode *pErrorCode)
 {
     return uregex_clone(regexp, pErrorCode);
 }
@@ -449,3 +450,98 @@ int32_t __hs_uregex_group(URegularExpression *regexp, int32_t groupNum,
 {
     return uregex_group(regexp, groupNum, dest, destCapacity, status);
 }
+
+USpoofChecker *__hs_uspoof_open(UErrorCode *status)
+{
+    return uspoof_open(status);
+}
+
+USpoofChecker *__hs_uspoof_openFromSerialized(const void *data, int32_t length,
+                                              int32_t *pActualLength,
+                                              UErrorCode *status)
+{
+    return uspoof_openFromSerialized(data, length, pActualLength, status);
+}
+
+USpoofChecker *__hs_uspoof_openFromSource(const char *confusables,
+                                          int32_t confusablesLen,
+                                          const char *confusablesWholeScript,
+                                          int32_t confusablesWholeScriptLen,
+                                          int32_t *errType,
+                                          UParseError *parseError,
+                                          UErrorCode *status)
+{
+    // Work around missing call to umtx_initOnce() in uspoof_openFromSource()
+    // causing crash when gNfdNormalizer is accessed
+    uspoof_getInclusionSet(status);
+    return uspoof_openFromSource(confusables, confusablesLen,
+                                 confusablesWholeScript,
+                                 confusablesWholeScriptLen,
+                                 errType, parseError, status);
+}
+
+void __hs_uspoof_setChecks(USpoofChecker *sc, int32_t checks,
+                           UErrorCode *status)
+{
+    uspoof_setChecks(sc, checks, status);
+}
+
+int32_t __hs_uspoof_getChecks(const USpoofChecker *sc, UErrorCode *status)
+{
+    return uspoof_getChecks(sc, status);
+}
+
+void __hs_uspoof_setRestrictionLevel(USpoofChecker *sc, URestrictionLevel level)
+{
+    uspoof_setRestrictionLevel(sc, level);
+}
+
+URestrictionLevel __hs_uspoof_getRestrictionLevel(const USpoofChecker *sc)
+{
+    return uspoof_getRestrictionLevel(sc);
+}
+
+void __hs_uspoof_setAllowedLocales(USpoofChecker *sc, const char *localesList,
+                                   UErrorCode *status)
+{
+    uspoof_setAllowedLocales(sc, localesList, status);
+}
+
+const char *__hs_uspoof_getAllowedLocales(USpoofChecker *sc, UErrorCode *status)
+{
+    return uspoof_getAllowedLocales(sc, status);
+}
+
+int32_t __hs_uspoof_check(USpoofChecker *sc, const UChar *id,
+                          int32_t length, int32_t *position,
+                          UErrorCode *status)
+{
+    return uspoof_check(sc, id, length, position, status);
+}
+
+int32_t __hs_uspoof_areConfusable(USpoofChecker *sc,
+                                  const UChar *id1, int32_t length1,
+                                  const UChar *id2, int32_t length2,
+                                  UErrorCode *status)
+{
+    return uspoof_areConfusable(sc, id1, length1, id2, length2, status);
+}
+
+int32_t __hs_uspoof_getSkeleton(USpoofChecker *sc,
+                                int32_t type, const UChar *id, int32_t length,
+                                UChar *dest, int32_t destCapacity,
+                                UErrorCode *status)
+{
+    return uspoof_getSkeleton(sc, type, id, length, dest, destCapacity, status);
+}
+
+int32_t __hs_uspoof_serialize(USpoofChecker *sc, void *data, int32_t capacity,
+                              UErrorCode *status)
+{
+    return uspoof_serialize(sc, data, capacity, status);
+}
+
+void __hs_uspoof_close(USpoofChecker *sc)
+{
+    uspoof_close(sc);
+}
