@@ -11,6 +11,7 @@
 #include "unicode/uiter.h"
 #include "unicode/unorm.h"
 #include "unicode/uregex.h"
+#include "unicode/uspoof.h"
 #include "unicode/ustring.h"
 
 #include <stdint.h>
@@ -26,7 +27,7 @@ void __hs_ubrk_setText(UBreakIterator* bi, const UChar *text,
 UBreakIterator * __hs_ubrk_safeClone(const UBreakIterator *bi,
 				     void *stackBuffer, int32_t *pBufferSize,
 				     UErrorCode *status);
-int32_t __hs_ubrk_current(UBreakIterator *bi);
+int32_t __hs_ubrk_current(const UBreakIterator *bi);
 int32_t __hs_ubrk_first(UBreakIterator *bi);
 int32_t __hs_ubrk_last(UBreakIterator *bi);
 int32_t __hs_ubrk_next(UBreakIterator *bi);
@@ -80,7 +81,6 @@ UCollator* __hs_ucol_safeClone(const UCollator *coll,
 int32_t __hs_ucol_getSortKey(const UCollator *coll,
 			     const UChar *source, int32_t sourceLength,
 			     uint8_t *result, int32_t resultLength);
-UBool __hs_ucol_equals(const UCollator *source, const UCollator *target);
 
 /* ucnv.h */
 
@@ -142,8 +142,8 @@ void __hs_uregex_setTimeLimit(URegularExpression *regexp,
 void __hs_uregex_setStackLimit(URegularExpression *regexp,
 			       int32_t limit, UErrorCode *status);
 void __hs_uregex_close(URegularExpression *regexp);
-URegularExpression *__hs_uregex_clone(URegularExpression *regexp,
-				      UErrorCode *pErrorCode);
+URegularExpression * __hs_uregex_clone(const URegularExpression *regexp,
+				       UErrorCode *pErrorCode);
 const UChar *__hs_uregex_pattern(const URegularExpression *regexp,
 				 int32_t *patLength, UErrorCode *status);
 int32_t __hs_uregex_flags(const URegularExpression *regexp,
@@ -176,3 +176,45 @@ int32_t __hs_u_strToLower(UChar *dest, int32_t destCapacity,
 			  const UChar *src, int32_t srcLength,
 			  const char *locale, UErrorCode *pErrorCode);
 int32_t __hs_u_strCompareIter(UCharIterator *iter1, UCharIterator *iter2);
+
+/* uspoof.h */
+
+USpoofChecker *__hs_uspoof_open(UErrorCode *status);
+USpoofChecker *__hs_uspoof_openFromSerialized(const void *data, int32_t length,
+                                              int32_t *pActualLength,
+                                              UErrorCode *status);
+USpoofChecker *__hs_uspoof_openFromSource(const char *confusables,
+                                          int32_t confusablesLen,
+                                          const char *confusablesWholeScript,
+                                          int32_t confusablesWholeScriptLen,
+                                          int32_t *errType,
+                                          UParseError *parseError,
+                                          UErrorCode *status);
+void __hs_uspoof_setChecks(USpoofChecker *sc, int32_t checks,
+                           UErrorCode *status);
+int32_t __hs_uspoof_getChecks(const USpoofChecker *sc, UErrorCode *status);
+
+// Yes, these really don't take UErrorCode *..
+void __hs_uspoof_setRestrictionLevel(USpoofChecker *sc,
+                                     URestrictionLevel restrictionLevel);
+URestrictionLevel __hs_uspoof_getRestrictionLevel(const USpoofChecker *sc);
+
+void __hs_uspoof_setAllowedLocales(USpoofChecker *sc, const char *localesList,
+                                   UErrorCode *status);
+const char *__hs_uspoof_getAllowedLocales(USpoofChecker *sc,
+                                          UErrorCode *status);
+
+int32_t __hs_uspoof_check(USpoofChecker *sc, const UChar *id,
+                          int32_t length, int32_t *position,
+                          UErrorCode *status);
+int32_t __hs_uspoof_areConfusable(USpoofChecker *sc,
+                                  const UChar *id1, int32_t length1,
+                                  const UChar *id2, int32_t length2,
+                                  UErrorCode *status);
+int32_t __hs_uspoof_getSkeleton(USpoofChecker *sc, int32_t checks,
+                                const UChar *id, int32_t length,
+                                UChar *dest, int32_t destCapacity,
+                                UErrorCode *status);
+int32_t __hs_uspoof_serialize(USpoofChecker *sc, void *data, int32_t capacity,
+                              UErrorCode *status);
+void __hs_uspoof_close(USpoofChecker *sc);
